@@ -272,14 +272,35 @@ class BuilderTests(unittest.TestCase):
     def test_can_add_empty_undirected_relationship_with_labels(self):
         p = Pypher()
         p.relationship(labels=['one', 'two', 'three'])
-        exp = '-[:`one`:`two`:`three`]-'
+        exp = '-[:`one`|`two`|`three`]-'
+
+        self.assertEqual(str(p), exp)
+
+    def test_can_add_empty_undirected_relationship_with_types(self):
+        p = Pypher()
+        p.relationship(types=['one', 'two', 'three'])
+        exp = '-[:`one`|`two`|`three`]-'
+
+        self.assertEqual(str(p), exp)
+
+    def test_can_add_empty_undirected_relationship_with_labels_and_types_but_uses_types(self):
+        p = Pypher()
+        p.relationship(labels=[1, 2, 3], types=['one', 'two', 'three'])
+        exp = '-[:`one`|`two`|`three`]-'
+
+        self.assertEqual(str(p), exp)
+
+    def test_can_add_empty_undirected_relationship_with_labels_and_types_but_uses_labels(self):
+        p = Pypher()
+        p.relationship(labels=[1, 2, 3], types=None)
+        exp = '-[:`1`|`2`|`3`]-'
 
         self.assertEqual(str(p), exp)
 
     def test_can_add_named_undirected_relationship_with_labels(self):
         p = Pypher()
         p.relationship(variable='test', labels=['one', 'two', 'three'])
-        exp = '-[test:`one`:`two`:`three`]-'
+        exp = '-[test:`one`|`two`|`three`]-'
 
         self.assertEqual(str(p), exp)
 
@@ -291,7 +312,7 @@ class BuilderTests(unittest.TestCase):
             name=name, age=age)
         c = str(p)
         params = p.bound_params
-        exp = '-[test:`one`:`two`:`three` {{`age`: ${a}, `name`: ${n}}}]-'.format(
+        exp = '-[test:`one`|`two`|`three` {{`age`: ${a}, `name`: ${n}}}]-'.format(
             n=get_dict_key(params, name), a=get_dict_key(params, age))
 
         self.assertEqual(str(p), exp)
@@ -370,7 +391,7 @@ class BuilderTests(unittest.TestCase):
         p.func(f, one, two)
         c = str(p)
         params = p.bound_params
-        exp = '{}({}, {})'.format(f, get_dict_key(params, one),
+        exp = '{}(${}, ${})'.format(f, get_dict_key(params, one),
             get_dict_key(params, two))
 
         self.assertEqual(c, exp)
@@ -399,7 +420,7 @@ class BuilderTests(unittest.TestCase):
         p.n.property('name').IN(one, two, three)
         c = str(p)
         params = p.bound_params
-        exp = 'n.`name` IN [{}, {}, {}]'.format(get_dict_key(params, one),
+        exp = 'n.`name` IN [${}, ${}, ${}]'.format(get_dict_key(params, one),
             get_dict_key(params, two), get_dict_key(params, three))
 
         self.assertEqual(c, exp)
@@ -411,13 +432,14 @@ class BuilderTests(unittest.TestCase):
         p.n.property('name').comp(__.field | three)
         c = str(p)
         params = p.bound_params
-        exp = 'n.`name` [field | {}]'.format(get_dict_key(params, three))
+        exp = 'n.`name` [field | ${}]'.format(get_dict_key(params, three))
 
         self.assertEqual(c, exp)
         self.assertEqual(1, len(params))
 
     def test_can_add_single_label(self):
         p = Pypher()
+
         p.n.label('one')
         exp = 'n:`one`'
 
@@ -425,7 +447,7 @@ class BuilderTests(unittest.TestCase):
 
     def test_can_add_multiple_labels(self):
         p = Pypher()
-        p.n.label('one', 'two', 'three', 'four')
+        p.n.label(['one', 'two', 'three', 'four'])
         exp = 'n:`one`:`two`:`three`:`four`'
 
         self.assertEqual(str(p), exp)
@@ -461,7 +483,7 @@ class OperatorTests(unittest.TestCase):
         p.one + s
         c = str(p)
         params = p.bound_params
-        exp = 'one + {s}'.format(s=get_dict_key(params, s))
+        exp = 'one + ${s}'.format(s=get_dict_key(params, s))
 
         self.assertEqual(c, exp)
         self.assertEqual(1, len(params))
@@ -472,7 +494,7 @@ class OperatorTests(unittest.TestCase):
         s + p.one
         c = str(p)
         params = p.bound_params
-        exp = '{s} + one'.format(s=get_dict_key(params, s))
+        exp = '${s} + one'.format(s=get_dict_key(params, s))
 
         self.assertEqual(c, exp)
         self.assertEqual(1, len(params))
@@ -484,7 +506,7 @@ class OperatorTests(unittest.TestCase):
         p.one + a.two + s
         c = str(p)
         params = p.bound_params
-        exp = 'one + two + {s}'.format(s=get_dict_key(params, s))
+        exp = 'one + two + ${s}'.format(s=get_dict_key(params, s))
 
         self.assertEqual(c, exp)
         self.assertEqual(1, len(params))
@@ -520,7 +542,7 @@ class OperatorTests(unittest.TestCase):
         a - p.two
         c = str(p)
         params = p.bound_params
-        exp = '{} - two'.format(get_dict_key(params, a))
+        exp = '${} - two'.format(get_dict_key(params, a))
 
         self.assertEqual(str(p), exp)
 
@@ -546,7 +568,7 @@ class OperatorTests(unittest.TestCase):
         a * p.two
         c = str(p)
         params = p.bound_params
-        exp = '{} * two'.format(get_dict_key(params, a))
+        exp = '${} * two'.format(get_dict_key(params, a))
 
         self.assertEqual(str(p), exp)
 
@@ -572,7 +594,7 @@ class OperatorTests(unittest.TestCase):
         a / p.two
         c = str(p)
         params = p.bound_params
-        exp = '{} / two'.format(get_dict_key(params, a))
+        exp = '${} / two'.format(get_dict_key(params, a))
 
         self.assertEqual(str(p), exp)
 
@@ -598,7 +620,7 @@ class OperatorTests(unittest.TestCase):
         a % p.two
         c = str(p)
         params = p.bound_params
-        exp = '{} % two'.format(get_dict_key(params, a))
+        exp = '${} % two'.format(get_dict_key(params, a))
 
         self.assertEqual(str(p), exp)
 
@@ -616,7 +638,7 @@ class OperatorTests(unittest.TestCase):
         a & p.two
         c = str(p)
         params = p.bound_params
-        exp = '{} & two'.format(get_dict_key(params, a))
+        exp = '${} & two'.format(get_dict_key(params, a))
 
         self.assertEqual(str(p), exp)
 
@@ -642,7 +664,7 @@ class OperatorTests(unittest.TestCase):
         a | p.two
         c = str(p)
         params = p.bound_params
-        exp = '{} | two'.format(get_dict_key(params, a))
+        exp = '${} | two'.format(get_dict_key(params, a))
 
         self.assertEqual(str(p), exp)
 
@@ -668,7 +690,7 @@ class OperatorTests(unittest.TestCase):
         a ^ p.two
         c = str(p)
         params = p.bound_params
-        exp = '{} ^ two'.format(get_dict_key(params, a))
+        exp = '${} ^ two'.format(get_dict_key(params, a))
 
         self.assertEqual(str(p), exp)
 
